# Installation

You can get started using Benjy in a few ways

#### **From source**

The core project can be installed from source on github

```bash 
git clone https://github.com/grai-io/benjy
cd benjy
pip install .
```

#### **Pip**

```
pip install benjy
```

#### **Docker**

!!! note
    Coming soon.


